@@ -6,8 +6,8 @@ import enum
 from collections.abc import Sequence
 
 
-gitdir = None
-worktree = None
+gitdir: 'str|None' = None
+worktree: 'str|None' = None
 
 
 CalledProcessError = subprocess.CalledProcessError
@@ -15,7 +15,7 @@ TimeoutExpired = subprocess.TimeoutExpired
 
 class CommandError(Exception):
 
-	def __init__(self, cmd: 'Sequence[str]', err: BaseException) -> None:
+	def __init__(self, cmd: 'Sequence[str]', err: 'BaseException|str') -> None:
 		exception: 'BaseException|None'
 		returncode: 'int|None'
 		error: 'str'
@@ -88,7 +88,7 @@ class Runner:
 			else:
 				return self.RETURNCODE_PROGRAM_NOT_FOUND
 
-	def run_and_get_output(self, cmd: 'Sequence[str]', *, ignore_returncode: bool = False) -> 'Sequence[str]':
+	def run_and_get_output(self, cmd: 'Sequence[str]', *, ignore_returncode: bool = False) -> 'str':
 		"""
 		Executes cmd without a shell and returns stdout as unicode/str.
 		Raises CommandError if program is not found or fails.
