@@ -326,7 +326,7 @@ class Model(Runner):
 		cls._remote_branches = None
 
 
-_cmd_grep_todo = ["git", "grep", "--no-index", "--exclude-standard", "-n", "-I", "-E", '(#|%|"|//)TODO\>|\<TODO[:]', '--', settings.WC_GIT_ROOT]
+_cmd_grep_todo = ["git", "grep", "-n", "-I", "-E", '(#|%|"|//)TODO\>|\<TODO[:]', '--', settings.WC_GIT_ROOT]
 
 class LogModel(Model):
 
@@ -340,7 +340,7 @@ class LogModel(Model):
 	cmd_unreachable = ["git", "fsck", "--unreachable"]
 	cmd_grep_todo_quiet = Model.replace_in_cmd_with_several(_cmd_grep_todo, 'grep', ['grep', '--quiet'])
 
-	timeout = .5
+	timeout = 2
 
 	@classmethod
 	def append_cmd_log(cls, options):
