@@ -30,7 +30,7 @@ from . import check
 main.DetailsView.max_lines_per_file = 2000
 
 
-def run():
+def run() -> None:
 	import sys
 
 	args = sys.argv[1:]
